import numpy as np
import vtk

def render_lamp(shade_file_path,
                base_file_path, 
                chord_file_path,
                image_file_path,
                color):
    
    # create a rendering window and renderer
    ren = vtk.vtkRenderer()
    ren.SetBackground(1.0, 1.0, 1.0)
    renWin = vtk.vtkRenderWindow()
    renWin.AddRenderer(ren)
    WIDTH=640
    HEIGHT=480
    renWin.SetSize(WIDTH,HEIGHT)
     
    # create a renderwindowinteractor
    iren = vtk.vtkRenderWindowInteractor()
    iren.SetRenderWindow(renWin)

    # shade
    reader = vtk.vtkSTLReader()
    reader.SetFileName(shade_file_path)
    reader.Update()
    shade = reader.GetOutput()
    shade_mapper = vtk.vtkPolyDataMapper()
    shade_mapper.SetInputData(shade)
    shade_actor = vtk.vtkActor()
    shade_actor.SetMapper(shade_mapper)
    shade_actor.GetProperty().SetColor(np.array(color)/255.0)
    shade_actor.GetProperty().SetAmbient(0.3)
    shade_actor.GetProperty().SetDiffuse(0.75)
    shade_actor.GetProperty().SetSpecular(0.5)
    shade_actor.GetProperty().SetOpacity(0.4)
    
    # base
    base_reader = vtk.vtkSTLReader()
    base_reader.SetFileName(base_file_path)
    base_reader.Update()
    base = base_reader.GetOutput()
    base_mapper = vtk.vtkPolyDataMapper()
    base_mapper.SetInputData(base)
    base_actor = vtk.vtkActor()
    base_actor.SetMapper(base_mapper) 
    base_actor.GetProperty().SetColor(16.0/255.0, 17.0/255.0, 17.0/255.0)
#     
#     # chord
    chord_reader = vtk.vtkSTLReader()
    chord_reader.SetFileName(chord_file_path)
    chord_reader.Update()
    chord = chord_reader.GetOutput()
    chord_mapper = vtk.vtkPolyDataMapper()
    chord_mapper.SetInputData(chord)
    chord_actor = vtk.vtkActor()
    chord_actor.SetMapper(chord_mapper) 
    chord_actor.GetProperty().SetColor(16.0/255.0, 17.0/255.0, 17.0/255.0)
    
    # Add a light
    light = vtk.vtkLight()
    light.SetPositional(True)
    light.SetLightTypeToSceneLight()
    light.SetFocalPoint(0.0,-100.0, 0.0)
    light.SetIntensity(1.0)
    lightActor = vtk.vtkLightActor()
    lightActor.SetLight(light)

    light.SetColor(0.0,0.0,0.0)
    light.SetSwitch(1)
    light.SetConeAngle(60)
    ren.AddViewProp(lightActor)
    
    cone = vtk.vtkConeSource()
    cone.SetResolution(60)
    cone.SetCenter(0.0,-150.0,0)
    cone.SetHeight(20.0)
    cone.SetRadius(20.0)
 
    cone_mapper = vtk.vtkPolyDataMapper()
    cone_mapper.SetInputConnection(cone.GetOutputPort())
    cone_mapper.SetScalarVisibility(0)
    
    cone_actor = vtk.vtkActor()
    cone_actor.SetMapper(cone_mapper)
    cone_actor.SetVisibility(1)
    cone_actor.GetProperty().SetColor(1.0, 1.0, 1.0)
     
    # assign actor to the renderer
    ren.AddActor(shade_actor)
    ren.AddActor(base_actor)
    ren.AddActor(chord_actor)
    #ren.AddActor(cone_actor)

    # Do render and output
    #iren.Initialize()
    renWin.Modified()
    renWin.Render()
    ren.AddLight(light)

    window_to_image = vtk.vtkWindowToImageFilter()
    window_to_image.SetInput(renWin)
    window_to_image.Update()
    
    png_writer = vtk.vtkPNGWriter()
    png_writer.SetFileName(image_file_path)
    png_writer.SetInputData(window_to_image.GetOutput())
    png_writer.Write()
    #iren.Start()
